@@ -217,7 +217,7 @@ sub as_json {
   return $self->to_hash(@args);
 }
 
-sub TO_JSON { shift->as_json(1) }
+sub TO_JSON { +{ shift->as_json(1) } }
 
 # Adds +message+ to the error messages and used validator type to +details+ on +attribute+.
 # More than one error can be added to the same +attribute+.
